Struct CommitMessageOptions

pub struct CommitMessageOptions {
    pub message: Option<String>,
    pub script: Option<PathBuf>,
}

Fields

message: Option<String>

Static commit message to use for all commits

script: Option<PathBuf>

Path to executable script that generates commit messages. The path can be absolute or relative to the repository. The script is executed with the repository as working directory and must output the message to stdout.